# KID-PPG: Knowledge-Informed Deep Learning for Extracting Heart Rate from Photoplethysmography Signals 

KID-PPG is the first ever publicly available pre-trained deep learning model for PPG Heart Rate inference, proposed [here](https://infoscience.epfl.ch/record/310896?ln=en&v=pdf).

# Installation
KID-PPG is readily available in pip. 

### Install from pip
Install KID-PPG from pip \
`pip install kid-ppg`

### Install from source
Clone this directory \
`git clone https://github.com/esl-epfl/KID-PPG.git`

Install the cloned repository \
`pip install ./KID-PPG`

# Usage

For an introductory demo on how to use KID-PPG for heart rate extraction check this [Google Colab Demo](https://colab.research.google.com/drive/1I7lP_elVuzf3sn2Tlm0QsgarUR0_9z-l?usp=share_link). The ```matplotlib``` python package is
required to run the demo.

# Reference

Please use the following Bibtext entry to cite KID-PPG.

```
@article{kechris2024kid,
  title={KID-PPG: Knowledge Informed Deep Learning for Extracting Heart Rate from a Smartwatch},
  author={Kechris, Christodoulos and Dan, Jonathan and Miranda Calero, Jos{\'e} Angel and Atienza Alonso, David},
  year={2024}
}
```